@echo OFF
rem  * ************************************************************************
rem  *              DIRCOMTEST1ST.cmd - a Windows Command File                *
rem  *          This Batch Job is provided by SimoTime Technologies           *
rem  *              (C) Copyright 1987-2019 All Rights Reserved               *
rem  *                Web Site URL:   http://www.simotime.com                 *
rem  *                      e-mail:   helpdesk@simotime.com                   *
rem  * ************************************************************************
rem  *
rem  * Create two files that contain a list of members from the specified
rem  * folders.
rem  *
rem  * The files should not contain directory names because of the "/a-d".
rem  *
rem  * The files could be sorted using the "/on" parameter that is an attribute
rem  * of the DIR command. However, the "/on" does not provide a directory
rem  * listing in an ASCII collating sequence.
rem  * Instead of the upper case letters being sorted before the lower case
rem  * letters the cases are intertwined. This is also referred to as a
rem  * case-insensitive sort. For example, the "/on" arranges the
rem  * list "A,a,B,b,C,c,D,d, etc..." and the ASCII collating sequence
rem  * is "A,B,C,D, etc..." followed by "a,b,c,d, etc...".
rem  *
rem  * The files will be processed by the Micro Focus SORT program to drop
rem  * records that have a space in position 1.
rem  * Also, the final step in this process uses a COBOL program to compare the
rem  * two files and this program depends on the files being in an ASCII
rem  * collating sequence by name in order to track inserts and deletes.
rem  *
rem  * ********************************************************************
rem  * Step   1 of 2  Set the global environment variables...
rem  *
     set CmdName=DIRCOMTEST1ST
     call ..\Env1BASE %CmdName%
     if "%SYSLOG%" == "" set syslog=c:\SimoLIBR\LOGS\SimoTime.LOG
rem  *
     call SimoNOTE "*******************************************************%CmdName%"
     call SimoNOTE "Starting CmdName %CmdName%.CMD"
rem  *
rem  *
rem  ***************************************************************************
rem  * List the contents of the two directories
rem  *
     dir %BaseLib1%\myDirectoryOne\*.* /a-d >%BASECAT%\Wrk1\Work01.TXT
     dir %BaseLib1%\myDirectoryTwo\*.* /a-d >%BASECAT%\Wrk1\Work02.TXT
rem  ***************************************************************************
rem  * Execute the script to sort and compare the two directory listings
     call ezDirListCompare %BASECAT%\Wrk1\Work01.TXT %BASECAT%\Wrk1\Work02.TXT
     if not "%ERRORLEVEL%" == "0" set JobStatus=0010
     if not "%JobStatus%" == "0000" goto :EojNOK
rem  *
rem  ***************************************************************************
:EojAOK
     call SimoNOTE "Finished CmdName %CmdName%.CMD, Job Status is %JobStatus% "
     goto :End
:EojNOK
     call SimoNOTE "ABENDING CmdName %CmdName%.CMD, Job Status is %JobStatus% "
     goto :End
:End
     call SimoNOTE "Conclude SysOut is %SYSOUT%"
     call SimoNOTE "Conclude SysLog is %SYSLOG%"
     if not "%1" == "nopause" pause
     exit /B %JobStatus%
