@echo OFF
rem  * ************************************************************************
rem  *              ezDirCompare.CMD - a Windows Command File                 *
rem  *           This program is provided by SimoTime Technologies            *
rem  *              (C) Copyright 1987-2019 All Rights Reserved               *
rem  *                Web Site URL:   http://www.simotime.com                 *
rem  *                      e-mail:   helpdesk@simotime.com                   *
rem  * ************************************************************************
rem  *
rem  * Create two files that contains a list of members from the specified
rem  * folders.
rem  *
rem  * The files should not contain directory names because of the "/a-d".
rem  *
rem  * The files could be sorted using the "/on" parameter and attribute of
rem  * the DIR command. However, the "/on" does not provide a directory listing
rem  * in an ASCII collating sequence.
rem  * Instead of the upper case letters being sorted before the lower case
rem  * letters the cases are intertwined. For example, the "/on" arranges the
rem  * list "A,a,B,b,C,c,D,d, etc..." and the ASCII collating sequence
rem  * is "A,B,C,D, etc..." followed by "a,b,c,d, etc...".
rem  *
rem  * The files will be processed by the Micro Focus SORT program to drop
rem  * records that have a space in position 1.
rem  * Also, the final step in this process uses a COBOL program to compare the
rem  * two files and this program depends on the files being in an ASCII
rem  * collating sequence by name in order to track inserts and deletes.
rem  *
rem  * Set environment variables and delete any work files created by a
rem  * previous run of this procedure.
rem  *
     call ..\Env1BASE
     set UtlName=ezDirCompare
     call SimoNOTE "Starting UtlName %UtlName%.CMD"
rem  *
rem  ***************************************************************************
rem  * List the contents of the two directories
rem  *
     if "%1" == "" set JobStatus=0011
     if not %JobStatus%==0000 goto :EojNOK
     if "%2" == "" set JobStatus=0012
     if not %JobStatus%==0000 goto :EojNOK
     call SimoNOTE "DataTake Parm01=%1"
     call SimoNOTE "DataTake Parm02=%2"
     if not exist %1 set JobStatus=0013
     if not %JobStatus%==0000 goto :EojNOK
     if not exist %2 set JobStatus=0014
     if not %JobStatus%==0000 goto :EojNOK
rem  *
     set SIMDIR01=%DataLib1%\Wrk1\Work01.TXT
     set SIMDIR02=%DataLib1%\Wrk1\Work02.TXT
     dir %1\*.* /a-d >%SIMDIR01%
     dir %2\*.* /a-d >%SIMDIR02%
rem  *
     set SIMSRTS1=%DataLib1%\Wrk1\SIMSRTS1.TXT
     set SIMSRTS2=%DataLib1%\Wrk1\SIMSRTS2.TXT
rem  *
     call SimoNOTE "Step 010 Delete previously created work files"
     if exist %SIMSRTS1% erase %SIMSRTS1%
     if exist %SIMSRTS2% erase %SIMSRTS2%
rem  *
     call SimoNOTE "Step 020 Sort the Directory Listings"
     call SimoNOTE "DataTake SimDir01=%1"
     call SimoNOTE "DataTake SimDir02=%2"
rem  *
     call SimoNOTE "Step 021 Sort Listing 01 File"
     set SYSOUT_SAVE=%SYSOUT%
     set SYSOUT=%BaseLib1%\LOGS\SYSOUT_ezDirCompareSort01.TXT
     mfsort sort fields=(40,48,ch,a) use %SIMDIR01% org ls record (f 256) give %SIMSRTS1% include cond=(1,1,ss,ne,c' ')
     call SimoNOTE "Step 022 Sort Listing 02 File"
     set SYSOUT=%BaseLib1%\LOGS\SYSOUT_ezDirCompareSort02.TXT
     mfsort sort fields=(40,48,ch,a) use %SIMDIR02% org ls record (f 256) give %SIMSRTS2% include cond=(1,1,ss,ne,c' ')
     set SYSOUT=%SYSOUT_SAVE%
rem  *
rem  * The two sorted files will be compared, any mismatches will be
rem  * written to the SYSLOG file. A Micro Focus COBOL program (DIRCOMC1)
rem  * is used for this process. The source code for the compare program
rem  * was generated by a SimoTime Utility program. Since the two files
rem  * being compared are in sequence by the name field it will be possible
rem  * to track record inserts and deletes.
rem  *
     call SimoNOTE "Step 030 Compare the sorted list"
     set SIMDIR01=%SIMSRTS1%
     set SIMDIR02=%SIMSRTS2%
     run DIRCOMC1
     if not "%ERRORLEVEL%" == "0" set JobStatus=0030
     if not "%JobStatus%" == "0000" goto :EojNOK
rem  *
:EojAOK
     call SimoNOTE "Finished UtlName %UtlName%.CMD, Files are equal"
     goto :End
:EojNOK
     if  %JobStatus%==0011 (call SimoNOTE "ABENDING UtlName=%UtlName%.CMD, JobStatus=%JobStatus%, Parameter 1 Missing or Invalid"
                            goto :End)
     if  %JobStatus%==0012 (call SimoNOTE "ABENDING UtlName=%UtlName%.CMD, JobStatus=%JobStatus%, Parameter 2 Missing or Invalid"
                           goto :End)
     if  %JobStatus%==0013 (call SimoNOTE "ABENDING UtlName=%UtlName%.CMD, JobStatus=%JobStatus%, Parameter 1 Not Found"
                            goto :End)
     if  %JobStatus%==0014 (call SimoNOTE "ABENDING UtlName=%UtlName%.CMD, JobStatus=%JobStatus%, Parameter 2 Not Found"
                            goto :End)
     call SimoNOTE "ABENDING UtlName %UtlName%.CMD, JobStatus=%JobStatus%, Files are not equal"
:End
     exit /B %JobStatus%
