@echo OFF
rem  * ************************************************************************
rem  *             ezDirListCompare.CMD - a Windows Command File              *
rem  *           This program is provided by SimoTime Technologies            *
rem  *              (C) Copyright 1987-2019 All Rights Reserved               *
rem  *                Web Site URL:   http://www.simotime.com                 *
rem  *                      e-mail:   helpdesk@simotime.com                   *
rem  * ************************************************************************
rem  * Create two files that contains a list of members from the specified
rem  * folders.
rem  *
rem  * The files should not contain directory names because of the "/a-d".
rem  *
rem  * The files could be sorted using the "/on" parameter and attribute of
rem  * the DIR command. However, the "/on" does not provide a directory listing
rem  * in an ASCII collating sequence.
rem  * Instead of the upper case letters being sorted before the lower case
rem  * letters the cases are intertwined. For example, the "/on" arranges the
rem  * list "A,a,B,b,C,c,D,d, etc..." and the ASCII collating sequence
rem  * is "A,B,C,D, etc..." followed by "a,b,c,d, etc...".
rem  *
rem  * The files will be processed by the Micro Focus SORT program to drop
rem  * records that have a space in position 1.
rem  * Also, the final step in this process uses a COBOL program to compare the
rem  * two files and this program depends on the files being in an ASCII
rem  * collating sequence by name in order to track inserts and deletes.
rem  *
rem  * Set environment variables and delete any work files created by a
rem  * previous run of this procedure.
rem  *
     set UtlName=ezDirListCompare
     call ..\Env1BASE %UtlName%
     call SimoNOTE "Starting UtlName %UtlName%.CMD"
     set SIMSRTS1=%BaseCAT%\Wrk1\SIMSRTS1.TXT
     set SIMSRTS2=%BaseCAT%\Wrk1\SIMSRTS2.TXT
rem  *
     call SimoNOTE "Step 010 Delete previously created work files"
     if exist %SIMSRTS1% erase %SIMSRTS1%
     if exist %SIMSRTS2% erase %SIMSRTS2%
rem  *
     call SimoNOTE "Step 020 Sort the Directory Listings"
     call SimoNOTE "DataTake SimDir01=%1"
     call SimoNOTE "DataTake SimDir02=%2"
rem  *
     call SimoNOTE "Step 021 Sort Listing 01 File"
     set SYSOUT_SAVE=%SYSOUT%
     set SYSOUT=%BaseLib1%\LOGS\SYSOUT_ezDirCompareSort01.TXT
     mfsort sort fields=(40,48,ch,a) use %1 org ls record (f 256) give %SIMSRTS1% include cond=(1,1,ss,ne,c' ')
     call SimoNOTE "Step 022 Sort Listing 02 File"
     set SYSOUT=%BaseLib1%\LOGS\SYSOUT_ezDirCompareSort02.TXT
     mfsort sort fields=(40,48,ch,a) use %2 org ls record (f 256) give %SIMSRTS2% include cond=(1,1,ss,ne,c' ')
     set SYSOUT=%SYSOUT_SAVE%
rem  *
rem  * The two sorted files will be compared, any mismatches will be
rem  * written to the SYSLOG file. A Micro Focus COBOL program (DIRCOMC1)
rem  * is used for this process. The source code for the compare program
rem  * was generated by a SimoTime Utility program. Since the two files
rem  * being compared are in sequence by the name field it will be possible
rem  * to track record inserts and deletes.
rem  *
     call SimoNOTE "Step 030 Compare the sorted list"
     set SIMDIR01=%SIMSRTS1%
     set SIMDIR02=%SIMSRTS2%
     run DIRCOMC1
     if not "%ERRORLEVEL%" == "0" set JobStatus=0010
     if not "%JobStatus%" == "0000" goto :EojNOK
rem  *
:EojAok
     call SimoNOTE "Finished UtlName %UtlName%.CMD, Files are equal"
     goto :End
:EojNok
     call SimoNOTE "ABENDING UtlName %UtlName%.CMD, Files are not equal"
:End
     exit /B %JobStatus%
